
/*
* Licensed Materials: Property of IBM
* "Restricted Materials of IBM"
* 5724-I68.
* (C) Copyright IBM Corp. 2000, 2005 - All Rights Reserved.
* US Government Users Restricted Rights - Use, duplication or disclosure
* restricted by GSA ADP Schedule Contract with IBM Corp.
*/


package com.ibm.ccd.ui.dataobjects.attributes;


/*
 * Represents the Boolean values
 * limitation : The value is represented as String and doesn't support formats
 */
public class FlagAttribute extends StringEnumAttribute {
    private static final String[] flagEnum = { "true", "false" };

    public FlagAttribute(String name, boolean editable, int minimumOccurrence,
        int maximumOccurrence, String displayName) {
        super(name, flagEnum, editable, minimumOccurrence, maximumOccurrence,
            displayName);
        removeValues();
        setValue(flagEnum[1]);
    }

    public FlagAttribute(String name, String defaultValue, boolean editable,
        int minimumOccurrence, int maximumOccurrence, String displayName) {
        super(name, flagEnum, defaultValue, editable, minimumOccurrence,
            maximumOccurrence, displayName);
        removeValues();

        if (defaultValue != null) {
            setValue(defaultValue);
        } else {
            setValue(flagEnum[1]);
        }
    }

    public FlagAttribute(String name, String defaultValue, boolean editable,
        int minimumLength, int maximumLength, int minimumOccurrence,
        int maximumOccurrence, String displayName) {
        super(name, flagEnum, defaultValue, editable, minimumLength,
            maximumLength, minimumOccurrence, maximumOccurrence, displayName);
        removeValues();

        if (defaultValue != null) {
            setValue(defaultValue);
        } else {
            setValue(flagEnum[1]);
        }
    }

    public int getType() {
        return AttributeTypes.FLAG;
    }

    protected void checkValue(String value) {
        if ((enum == null) || (enum.length == 0)) {
            throw new IllegalArgumentException("Enum is Empty/Not defined for " +
                getName());
        }

        for (int i = 0; i < enum.length; ++i) {
            if (enum[i].equalsIgnoreCase(value)) {
                return;
            }
        }

        throw new IllegalArgumentException(" Not defined Enum for " + value +
            "in " + getName());
    }
}
